package com.ruoyi.service.impl;

import com.ruoyi.common.constant.HttpStatus;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.domain.CarReviewTask;
import com.ruoyi.domain.ReviewStandard;
import com.ruoyi.mapper.CarReviewTaskMapper;
import com.ruoyi.service.ReviewStandardService;
import com.ruoyi.service.StrategyCarReviewTask;
import com.ruoyi.web.response.CarReviewTaskViewResponse;
import com.ruoyi.web.response.SystemReviewTaskViewResponse;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;

import java.util.Date;
import java.util.List;

public class StrategyCarReviewTaskNew implements StrategyCarReviewTask, InitializingBean {

    @Autowired
    private StrategyCarReviewTaskContext strategyCarReviewTaskContext;

    @Autowired
    private ApplicationContext applicationContext;

    @Autowired
    private ReviewStandardService reviewStandardService;

    @Autowired
    private CarReviewTaskMapper carReviewTaskMapper;


    // NEW状态下
    // 1.standard字段查询当前最新问卷
    // 2.不查询场景变更任务
    // 3.无需联查问卷答案
    @Override
    public CarReviewTaskViewResponse doView(CarReviewTask carReviewTask) {
        // 获取最新问卷
        List<ReviewStandard> standardTree = reviewStandardService.findTree(carReviewTask.getStandardId(), ReviewStandard.TYPE_CAR);

        // 将问卷赋值到任务
        carReviewTask.setStandard(standardTree);

        // 生成返回结果
        CarReviewTaskViewResponse response = new CarReviewTaskViewResponse();
        response.setCarReviewTask(carReviewTask);

        return response;
    }

    @Override
    public void doStartReview(CarReviewTask carReviewTask) {
        carReviewTask.setReviewStartTime(new Date());
        carReviewTask.setReviewStatus(CarReviewTask.REVIEW_STATUS_PENDING);
        carReviewTaskMapper.updateById(carReviewTask);
    }

    @Override
    public void doSubmitReview(CarReviewTask carReviewTask) {
        throw new ServiceException("不能提交一个未开始的任务", HttpStatus.ERROR);
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        strategyCarReviewTaskContext.putResource(CarReviewTask.REVIEW_STATUS_NEW, applicationContext.getBean(this.getClass()));
    }
}
